@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Task::Kensho::OOP;
-# git description: v0.37-32-g6bd7a4b
-$Task::Kensho::OOP::VERSION = '0.38';
+package Task::Kensho::OOP; # git description: v0.38-57-gc1c0b50
 # ABSTRACT: A Glimpse at an Enlightened Perl: Object Oriented Programming
 
+our $VERSION = '0.39';
+
 __END__
 
 =pod
@@ -17,7 +17,7 @@ Task::Kensho::OOP - A Glimpse at an Enlightened Perl: Object Oriented Programmin
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
@@ -68,9 +68,53 @@ facilitates the ease and simplicity the distribution aims to achieve.
 
 =head2 L<Task::Kensho::OOP>: Object Oriented Programming
 
+=head3 L<Moo>
+
+Minimalist Object Orientation (with Moose compatibility)
+
+=head3 L<Moose>
+
+a postmodern object system for Perl5
+
+=head3 L<MooseX::Aliases>
+
+easy aliasing of methods and attributes in Moose
+
+=head3 L<MooseX::Getopt>
+
+a Moose role for processing command line options
+
+=head3 L<MooseX::NonMoose>
+
+easy subclassing of non-Moose classes
+
+=head3 L<MooseX::Role::Parameterized>
+
+Moose roles with composition parameters
+
+=head3 L<MooseX::SimpleConfig>
+
+a Moose role for setting attributes from a simple configuration file
+
+=head3 L<MooseX::StrictConstructor>
+
+a Moose extension that makes your object constructors blow up on unknown attributes
+
+=head3 L<Package::Variant>
+
+Parameterizable packages
+
 =head3 L<Task::Moose>
 
-Moose is a postmodern object system for Perl5. Task::Moose installs Moose and optionally a list of recommended modules that extend Moose.
+Task::Moose installs Moose and optionally a list of recommended modules that extend Moose.
+
+=head3 L<Type::Tiny>
+
+tiny, yet Moo(se)-compatible type constraints
+
+=head3 L<namespace::autoclean>
+
+keep imports out of your namespace (Moose-aware)
 
 =head1 INSTALLING
 
@@ -82,6 +126,11 @@ The C<cpanm> client requires interactive mode to be enabled for this to work:
 
     cpanm --interactive Task::Kensho::OOP
 
+=head1 SEE ALSO
+
+L<http://www.enlightenedperl.org/>,
+L<Perl::Dist::Strawberry|Perl::Dist::Strawberry>
+
 =head1 BUGS AND LIMITATIONS
 
 This list is by no means comprehensive of the "Good" Modules on CPAN.
@@ -93,25 +142,18 @@ starting place on the road to Enlightened Perl programming.
 Please report any bugs or feature requests to
 L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
-=head1 SEE ALSO
+bugs may be submitted through L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
-L<http://www.enlightenedperl.org/>,
-L<Perl::Dist::Strawberry|Perl::Dist::Strawberry>
+There is also an irc channel available for users of this distribution, at
+L<C<#epo> on C<irc.perl.org>|irc://irc.perl.org/#epo>.
 
 =head1 AUTHOR
 
 Chris Prather <chris@prather.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2008 by Chris Prather.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Leo Lapworth Chris Nehren
+=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Rick Leir
 
 =over 4
 
@@ -127,6 +169,17 @@ Leo Lapworth <leo@cuckoo.org>
 
 Chris Nehren <apeiron@cpan.org>
 
+=item *
+
+Rick Leir <rleir@leirtech.com>
+
 =back
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2008 by Chris Prather.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
